==> yubioath-desktop-2.1.0.tar.gz: yubioath-desktop-2.1.0/yubioath/yubicommon/setup/exe.py <==
# Copyright (c) 2013 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from setuptools import Command
from distutils.errors import DistutilsSetupError
import os
import json
import tempfile


class executable(Command):
    description = "create an executable"
    user_options = [
        ('debug', None, "build with debug flag"),
    ]
    boolean_options = ['debug']

    def initialize_options(self):
        self.debug = 0

    def finalize_options(self):
        self.cwd = os.getcwd()

    def run(self):
        if os.getcwd() != self.cwd:
            raise DistutilsSetupError("Must be in package root!")

        from PyInstaller.main import run as pyinst_run

        os.environ['pyinstaller_data'] = json.dumps({
            'debug': self.debug,
            'version': self.distribution.get_version(),
            'name': self.distribution.get_name(),
            'fullname': getattr(self.distribution, 'fullname',
                                self.distribution.get_name()),
            'ver_name': self.distribution.get_fullname(),
            'scripts': self.distribution.scripts
        })

        spec = tempfile.NamedTemporaryFile(suffix='.spec', delete=False)
        source = os.path.join(os.path.dirname(__file__), 'pyinstaller_spec.py')
        with open(source) as f:
            spec.write(f.read())
        spec_name = spec.name
        spec.close()
        pyinst_run([spec_name])
        os.unlink(spec_name)

        self.announce("Executable created!")

==> yubioath-desktop-2.2.1.tar.gz: yubioath-desktop-2.2.1/yubioath/yubicommon/setup/exe.py <==
# Copyright (c) 2013 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from __future__ import absolute_import

from setuptools import Command
from distutils.errors import DistutilsSetupError
import os
import json
import tempfile


class executable(Command):
    description = "create an executable"
    user_options = [
        ('debug', None, "build with debug flag"),
    ]
    boolean_options = ['debug']

    def initialize_options(self):
        self.debug = 0

    def finalize_options(self):
        self.cwd = os.getcwd()

    def run(self):
        if os.getcwd() != self.cwd:
            raise DistutilsSetupError("Must be in package root!")

        from PyInstaller.main import run as pyinst_run

        os.environ['pyinstaller_data'] = json.dumps({
            'debug': self.debug,
            'name': self.distribution.get_name(),
            'fullname': getattr(self.distribution, 'fullname',
                                self.distribution.get_name())
        })

        spec = tempfile.NamedTemporaryFile(suffix='.spec', delete=False)
        source = os.path.join(os.path.dirname(__file__), 'pyinstaller_spec.py')
        with open(source) as f:
            spec.write(f.read())
        spec_name = spec.name
        spec.close()
        pyinst_run([spec_name])
        os.unlink(spec_name)

        self.announce("Executable created!")
